==> kubernetes-model-extensions-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/extensions/DeploymentStrategyFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface DeploymentStrategyFluent<A extends DeploymentStrategyFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildRollingUpdate instead.
   * @return The buildable object.
   */
  @Deprecated
  public RollingUpdateDeployment getRollingUpdate();
  public RollingUpdateDeployment buildRollingUpdate();
  public A withRollingUpdate(RollingUpdateDeployment rollingUpdate);
  public Boolean hasRollingUpdate();
  public DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
  public DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(RollingUpdateDeployment item);
  public DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
  public DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
  public DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(RollingUpdateDeployment item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface RollingUpdateNested<N> extends Nested<N>,RollingUpdateDeploymentFluent<DeploymentStrategyFluent.RollingUpdateNested<N>>{
    public N and();
    public N endRollingUpdate();
    
  }
  
}

==> kubernetes-model-extensions-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/extensions/DeploymentStrategyFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DeploymentStrategyFluent<A extends DeploymentStrategyFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildRollingUpdate instead.
   * @return The buildable object.
   */
  @Deprecated
  public RollingUpdateDeployment getRollingUpdate();
  public RollingUpdateDeployment buildRollingUpdate();
  public A withRollingUpdate(RollingUpdateDeployment rollingUpdate);
  public Boolean hasRollingUpdate();
  public DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
  public DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(RollingUpdateDeployment item);
  public DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
  public DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
  public DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(RollingUpdateDeployment item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface RollingUpdateNested<N> extends Nested<N>,RollingUpdateDeploymentFluent<DeploymentStrategyFluent.RollingUpdateNested<N>>{
    public N and();
    public N endRollingUpdate();
    
  }
  
}
